/*
   SPDX-FileCopyrightText: 2024-2025 Laurent Montel <montel@kde.org>

   SPDX-License-Identifier: LGPL-2.0-or-later
*/
#pragma once
#include "libkaichatwidgets_export.h"
#include <QDebug>
#include <QStringList>
class LIBKAICHATWIDGETS_EXPORT WhatsNewInfo
{
public:
    WhatsNewInfo();
    ~WhatsNewInfo();

    [[nodiscard]] const QStringList &changes() const;
    void setChanges(const QStringList &newChanges);

    [[nodiscard]] const QStringList &newFeatures() const;
    void setNewFeatures(const QStringList &newNewFeatures);

    [[nodiscard]] const QStringList &bugFixings() const;
    void setBugFixings(const QStringList &newBugFixings);

    [[nodiscard]] const QString &version() const;
    void setVersion(const QString &newVersion);

private:
    QString mVersion;
    QStringList mChanges;
    QStringList mNewFeatures;
    QStringList mBugFixings;
};
Q_DECLARE_METATYPE(WhatsNewInfo)
Q_DECLARE_TYPEINFO(WhatsNewInfo, Q_RELOCATABLE_TYPE);
LIBKAICHATWIDGETS_EXPORT QDebug operator<<(QDebug d, const WhatsNewInfo &t);
